#include "../../base.shader"

struct VERT_OUTPUT2
{
	float4 location : POSITION;
	float4 color : COLOR0;
	float2 uv : TEXCOORD0;
	float2 uv2 : TEXCOORD1;
};

struct PIX_INPUT2
{
	float4 color : COLOR0;
	float2 uv : TEXCOORD0;
	float2 uv2 : TEXCOORD1;
};

float4x4 _transform;
float2 _stencilTargetRatio;
float2 _stencilTargetOffset;
VERT_OUTPUT2 vert(in VERT_INPUT input)
{
	VERT_OUTPUT2 output;
	output.location = mul(input.location, _transform);
	output.color = input.color;
	output.uv = input.uv;
	output.uv2.x = (output.location.x + 1) / 2 * _stencilTargetRatio.x + _stencilTargetOffset.x;
	output.uv2.y = (output.location.y - 1) / -2 * _stencilTargetRatio.y + _stencilTargetOffset.y;
	return output;
}

sampler2D _texture;
sampler2D _stencilTarget;
float4 _color;
float4 _allegianceColor;
PIX_OUTPUT pix(in PIX_INPUT2 input) : COLOR0
{
	float4 pixel = tex2D(_texture, input.uv);
	if(pixel.g > pixel.r && abs(pixel.r - pixel.b) < .025) // Replace green pixels with allegiance color.
	{
		float3 scaledAllegianceColor = _allegianceColor.rgb * pixel.g;
		float desaturation = pixel.r / pixel.g; // works because pixel.r == pixel.b (approximately)
		float desaturationValue = max(scaledAllegianceColor.r, max(scaledAllegianceColor.g, scaledAllegianceColor.b));
		float3 desaturationColor = float3(desaturationValue, desaturationValue, desaturationValue);
		pixel.rgb = scaledAllegianceColor * (1 - desaturation) + desaturationColor * desaturation;
	}

	pixel.a *= 1 - tex2D(_stencilTarget, input.uv2).a;
	return pixel * input.color * _color;
}